/**************************************************************************/
/*  NLS messsages definition.                                             */
/**************************************************************************/
#include "engmsg.h"
/* ---------------------------------------------------------------------- */
